@@ -2,18 +2,24 @@
 
 from . import core
 from . import exposition
-from . import process_collector
+from . import gc_collector
 from . import platform_collector
+from . import process_collector
+from . import registry
+from . import metrics_core
+from . import metrics
 
-__all__ = ['Counter', 'Gauge', 'Summary', 'Histogram']
+__all__ = ['Counter', 'Gauge', 'Summary', 'Histogram', 'Info', 'Enum']
 
-CollectorRegistry = core.CollectorRegistry
-REGISTRY = core.REGISTRY
-Metric = core.Metric
-Counter = core.Counter
-Gauge = core.Gauge
-Summary = core.Summary
-Histogram = core.Histogram
+CollectorRegistry = registry.CollectorRegistry
+REGISTRY = registry.REGISTRY
+Metric = metrics_core.Metric
+Counter = metrics.Counter
+Gauge = metrics.Gauge
+Summary = metrics.Summary
+Histogram = metrics.Histogram
+Info = metrics.Info
+Enum = metrics.Enum
 
 CONTENT_TYPE_LATEST = exposition.CONTENT_TYPE_LATEST
 generate_latest = exposition.generate_latest
@@ -33,6 +39,8 @@ PROCESS_COLLECTOR = process_collector.PROCESS_COLLECTOR
 PlatformCollector = platform_collector.PlatformCollector
 PLATFORM_COLLECTOR = platform_collector.PLATFORM_COLLECTOR
 
+GCCollector = gc_collector.GCCollector
+GC_COLLECTOR = gc_collector.GC_COLLECTOR
 
 if __name__ == '__main__':
     c = Counter('cc', 'A counter')
